#!/usr/bin/python3
""" Utility classes and functions """

from time import strftime, gmtime
import os
import boto3
import subprocess as sp
import threading


class Recording:
    """
    Simple class for Recording
    """

    def __init__(self):
        """
        """
        self.study = None
        self.path = None
        self.filename = None
        self.thread = None
        self.webcams = 0
        self.microphones = 0
        self.equipment =  { 
            'video0' : '',
            'video1' : '',
            'audio' : ''
        }
        self.cwd = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(__file__)))
        child = sp.Popen(os.path.join(self.cwd, 'scripts/get_equipment.sh'), stdout=sp.PIPE)
        devices = child.communicate()[0]
        for device in devices.rstrip().decode().split('\n'):
            if 'C920' in device:
                index = 'video' + str(self.webcams)
                self.equipment[index] = device
                self.webcams += 1
            elif 'C-Media_Electronics' in device:
                self.equipment['audio'] = device
                self.microphones += 1


    def start(self, study, participant, visit, time):
        """
        Starts a recording thread
        """
        self.study = study
        self.path = '/'.join([study, participant, visit])
        self.filename = '_'.join([study, participant, visit, time])
        self.thread = threading.Thread(target = self.recording_thread)
        self.thread.start()


    def stop(self):
        """
        Stops the recording process
        """
        os.system('kill ' + self.get_pid().decode())


    def recording_thread(self):
        """
        Calls the record script
        """
        child = sp.Popen('supervisorctl', 'start', 'record'], stdout=sp.PIPE)
        tc = child.communicate()[0]
        rc = child.returncode
        self.upload()
        while rc == 0:
            continue
            

    def upload(self):
        """
        Uploads an encrypted package to AWS S3
        """
        with open('/home/pi/.aws/credentials', 'r') as f:
            _, ACCESS_ID, ACCESS_KEY = (x.strip().split( )[-1] for x in f.readlines()[:])
        s3 = boto3.resource('s3',
            aws_access_key_id=ACCESS_ID,
            aws_secret_access_key=ACCESS_KEY
        )
        package = '/tmp/' + self.filename + '.tar.gz.enc'
        key = '/tmp/' + self.filename + '.key.enc'
        print(package)
        if self.study in {'MP18', 'MAPP3'}: 
            bucket = 'maps-eu-videos'
        else:
            bucket = 'maps-study-videos'
        s3.meta.client.upload_file(
            package,
            bucket, 
            '/'.join([self.path, 'package', package])
        )
        s3.meta.client.upload_file(
            key,
            bucket,
            '/'.join([self.path, 'key', key])
        )


    def get_pid(self):
        """
        Gets and returns ffmpeg pid
        """
        child = sp.Popen(['pidof', 'ffmpeg'], stdout=sp.PIPE)
        return child.communicate()[0]


    def list_equipment(self):
        """
        Lists connected USB recording devices
        """
        return self.webcams, self.microphones



def get_curtime():
    return strftime("%Y%m%d-%H%M%S", gmtime())


def app_version():
    pip = sp.Popen(["pip3", "freeze"], stdout=sp.PIPE)
    ver, er = pip.communicate()
    pos = str(ver).find('recogen') + 9
    return str(ver)[pos:pos+10].split("\\", 1)[0]
